#!/bin/sh

# \
  if (test -z "$WISH"); then export WISH=wish; fi
# \
  exec "$WISH" "$0" -name wish ${1+"$@"}

# ======================================================================

# example2.tcl --

# Label wrapping example.

# Version   : 0.0.1
# Author    : Mark G. Saye
# Email     : markgsaye@yahoo.com
# Copyright : Copyright (C) 2003
# Date      : April 20, 2003

# See the file "LICENSE.txt" or "LICENSE.html" for information on usage
# and distribution of this file, and for a DISCLAIMER OF ALL WARRANTIES.

# ======================================================================

# rename ::focus ::focus_
# proc ::focus {args} {
  # puts "focus \[$args\]"
  # uplevel [linsert $args 0 focus_]
# }

# ======================================================================

  package require label

# ======================================================================

  namespace eval example {}

# ======================================================================

proc example::main {{argc 0} {argv {}}} {

# ----------------------------------------------------------------------

  variable ns [namespace current]

# ----------------------------------------------------------------------

  wm withdraw .
  update idletasks

  set W .label_example2
  toplevel $W
  wm withdraw $W
  update idletasks

  wm title $W "Label Wrapping Example"
  wm protocol $W WM_DELETE_WINDOW exit

  tk_focusNext $W

  pack propagate $W 0
  wm geometry $W 500x300

  set image [image create photo]
  $image put red -to 0 0 16 16

  label $W.label \
    -bg white \
    -anchor nw \
    -highlightthickness 1 \
    -justify l \
    -padx 10 \
    -pady 10 \
    -takefocus 1

  set text "A label with a long text string to example auto-wrapping"

  set text "Label Wrapping

This is a demonstration of the label wrapping feature. To use, you\
should put the following code in your application:

	package require label
	# Create a new label
	label .label -text \"My Label Text\"
	bind .label <Configure> \[list label::wrap %W %w\]

You are using Tcl version $::tcl_patchLevel and Tk version\
$::tk_patchLevel."

  if { [catch {$W.label configure -compound left} err] } {
    append text " This version does not support compound images\
(labels with images and text), so there is no image to the left."
  } else {
    $W.label configure -image $image
    append text " This version supports compound images (labels with\
images and text), so you should see a red square image to the left."
  }

  append text "

If you resize this toplevel window, you should see the text in this\
label wrap to fit the width of the window."

  $W.label configure -text $text

  bind  $W.label <Configure> [list label::wrap %W %w]

# ----------------------------------------------------------------------

  button $W.button \
    -text Close \
    -default active \
    -command exit

  focus $W.button

# ----------------------------------------------------------------------

  pack $W.button -side bottom -anchor se
  pack $W.label  -side top -fill x -padx 20 -pady 20

# ----------------------------------------------------------------------

  wm deiconify $W
  raise $W

# ----------------------------------------------------------------------

  return

}

# ======================================================================

  if { [info exists argv0] && [string equal [info script] $argv0] } {
    example::main $argc $argv
  }

# ======================================================================

